@@ -24,7 +24,8 @@ class upconfig(object):
         """
         self.updatePath = os.path.join(path if path else proDir, f"{file_name}.ini")
         self.config = configparser.RawConfigParser()
-        self.config.read(self.updatePath, encoding="utf-8-sig")
+        with open(self.updatePath, encoding="utf-8-sig") as f:
+            self.config.read_file(f)
         self.update_tag = update_tag
 
     def get_information(self, name):
